/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ClientStateless.java 177 2006-03-10 15:10:04Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.examples.statelessbean;

import javax.naming.Context;
import javax.naming.InitialContext;

/**
 * Simple client of the stateless.
 * @author Florent Benoit
 */
public final class ClientStateless {

    /**
     * Utility class.
     */
    private ClientStateless() {

    }

    /**
     * Main method.
     * @param args the arguments (not required)
     * @throws Exception if exception is found.
     */
    public static void main(final String[] args) throws Exception {
        // if user don't use jclient/client container
        System.setProperty(Context.INITIAL_CONTEXT_FACTORY, "org.objectweb.carol.jndi.spi.MultiOrbInitialContextFactory");

        Context initialContext = new InitialContext();

        StatelessRemote statelessBean = (StatelessRemote) initialContext
                .lookup("org.objectweb.easybeans.examples.statelessbean.StatelessBean"
                        + "_" + StatelessRemote.class.getName() + "@Remote");

        System.out.println("Calling helloWorld method...");
        statelessBean.helloWorld();

        System.out.println("Add 1 + 2...");
        int resultAdd = statelessBean.add(1, 2);
        System.out.println("Sum = '" + resultAdd + "'.");

        // System.out.println("Div 1 / 0 (expect exception)...");
        // statelessBean.div(1, 0);

    }

}
